@@ -1,9 +1,10 @@
 list_df <- function(...) {
   df <- list(...)
-  if (length(df) > 0)
+  if (length(df) > 0) {
     attr(df, "row.names") <- .set_row_names(length(df[[1]]))
-  else
+  } else {
     attr(df, "row.names") <- .set_row_names(0L)
+  }
   class(df) <- "data.frame"
   df
 }
